@@ -5,7 +5,7 @@
  *	Manjeet Dahiya
  *
  * Source:
- *	http://code.google.com/p/qxmpp
+ *	https://github.com/qxmpp-project/qxmpp
  *
  * This file is a part of QXmpp library.
  *
@@ -30,7 +30,7 @@
 int main(int argc, char *argv[])
 {
     QCoreApplication app(argc, argv);
-    
+
     QXmppClient client;
     client.logger()->setLoggingType(QXmppLogger::StdoutLogging);
 
