@@ -6,7 +6,7 @@
  *  Jeremy Lainé
  *
  * Source:
- *	http://code.google.com/p/qxmpp
+ *	https://github.com/qxmpp-project/qxmpp
  *
  * This file is a part of QXmpp library.
  *
@@ -126,7 +126,7 @@ void xmppClient::slotCallReceived(QXmppCall *call)
                     this, SLOT(slotAudioModeChanged(QIODevice::OpenMode)));
     Q_ASSERT(check);
 
-    // accept call    
+    // accept call
     call->accept();
 }
 
