@@ -32,6 +32,7 @@
 
 #include "QXmppCodec_p.h"
 #include "QXmppRtpChannel.h"
+#include "QXmppRtpPacket.h"
 
 #include <cstring>
 
@@ -72,7 +73,7 @@ enum FragmentType {
     NoFragment = 0,
     StartFragment,
     MiddleFragment,
-    EndFragment,
+    EndFragment
 };
 
 static qint16 seg_aend[8] = {0x1F, 0x3F, 0x7F, 0xFF,
@@ -675,7 +676,7 @@ QList<QXmppVideoFrame> QXmppTheoraDecoder::handlePacket(const QXmppRtpPacket &pa
     QList<QXmppVideoFrame> frames;
 
     // theora deframing: draft-ietf-avt-rtp-theora-00
-    QDataStream stream(packet.payload);
+    QDataStream stream(packet.payload());
     quint32 theora_header;
     stream >> theora_header;
 
@@ -1184,9 +1185,10 @@ QXmppVideoFormat QXmppVpxDecoder::format() const
 QList<QXmppVideoFrame> QXmppVpxDecoder::handlePacket(const QXmppRtpPacket &packet)
 {
     QList<QXmppVideoFrame> frames;
+    const QByteArray payload = packet.payload();
 
     // vp8 deframing: http://tools.ietf.org/html/draft-westin-payload-vp8-00
-    QDataStream stream(packet.payload);
+    QDataStream stream(payload);
     quint8 vpx_header;
     stream >> vpx_header;
 
@@ -1197,7 +1199,7 @@ QList<QXmppVideoFrame> QXmppVpxDecoder::handlePacket(const QXmppRtpPacket &packe
         return frames;
     }
 
-    const int packetLength = packet.payload.size() - 1;
+    const int packetLength = payload.size() - 1;
 #ifdef QXMPP_DEBUG_VPX
     qDebug("Vpx fragment FI: %d, size %d", frag_type, packetLength);
 #endif
@@ -1215,12 +1217,12 @@ QList<QXmppVideoFrame> QXmppVpxDecoder::handlePacket(const QXmppRtpPacket &packe
 
     if (frag_type == NoFragment) {
         // unfragmented packet
-        if ((packet.payload[1] & 0x1) == 0 // is key frame
-            || packet.sequence == sequence) {
-            if (d->decodeFrame(packet.payload.mid(1), &frame))
+        if ((payload[1] & 0x1) == 0 // is key frame
+            || packet.sequence() == sequence) {
+            if (d->decodeFrame(payload.mid(1), &frame))
                 frames << frame;
 
-            sequence = packet.sequence + 1;
+            sequence = packet.sequence() + 1;
         }
 
         d->packetBuffer.resize(0);
@@ -1228,14 +1230,14 @@ QList<QXmppVideoFrame> QXmppVpxDecoder::handlePacket(const QXmppRtpPacket &packe
         // fragments
         if (frag_type == StartFragment) {
             // start fragment
-            if ((packet.payload[1] & 0x1) == 0 // is key frame
-                || packet.sequence == sequence) {
-                d->packetBuffer = packet.payload.mid(1);
-                sequence = packet.sequence + 1;
+            if ((payload[1] & 0x1) == 0 // is key frame
+                || packet.sequence() == sequence) {
+                d->packetBuffer = payload.mid(1);
+                sequence = packet.sequence() + 1;
             }
         } else {
             // continuation or end fragment
-            if (packet.sequence == sequence) {
+            if (packet.sequence() == sequence) {
                 const int packetPos = d->packetBuffer.size();
                 d->packetBuffer.resize(packetPos + packetLength);
                 stream.readRawData(d->packetBuffer.data() + packetPos, packetLength);
@@ -1258,6 +1260,7 @@ QList<QXmppVideoFrame> QXmppVpxDecoder::handlePacket(const QXmppRtpPacket &packe
 
 bool QXmppVpxDecoder::setParameters(const QMap<QString, QString> &parameters)
 {
+    Q_UNUSED(parameters);
     return true;
 }
 
