@@ -58,7 +58,7 @@ public:
         NoLogging = 0,      ///< Log messages are discarded
         FileLogging = 1,    ///< Log messages are written to a file
         StdoutLogging = 2,  ///< Log messages are written to the standard output
-        SignalLogging = 4,  ///< Log messages are emitted as a signal
+        SignalLogging = 4   ///< Log messages are emitted as a signal
     };
 
     /// This enum describes a type of log message.
@@ -70,7 +70,7 @@ public:
         WarningMessage = 4,     ///< Warning message
         ReceivedMessage = 8,    ///< Message received from server
         SentMessage = 16,       ///< Message sent to server
-        AnyMessage = 31,        ///< Any message type
+        AnyMessage = 31         ///< Any message type
     };
     Q_DECLARE_FLAGS(MessageTypes, MessageType)
 
