@@ -60,7 +60,7 @@ static const char *ns_xhtml = "http://www.w3.org/1999/xhtml";
 enum StampType
 {
     LegacyDelayedDelivery,  // XEP-0091: Legacy Delayed Delivery
-    DelayedDelivery,        // XEP-0203: Delayed Delivery
+    DelayedDelivery         // XEP-0203: Delayed Delivery
 };
 
 class QXmppMessagePrivate : public QSharedData
@@ -553,11 +553,15 @@ void QXmppMessage::parse(const QDomElement &element)
         {
             if (xElement.namespaceURI() == ns_legacy_delayed_delivery)
             {
-                // XEP-0091: Legacy Delayed Delivery
-                const QString str = xElement.attribute("stamp");
-                d->stamp = QDateTime::fromString(str, "yyyyMMddThh:mm:ss");
-                d->stamp.setTimeSpec(Qt::UTC);
-                d->stampType = LegacyDelayedDelivery;
+                // if XEP-0203 exists, XEP-0091 has no need to parse because XEP-0091 is no more standard protocol)
+                if (d->stamp.isNull())
+                {
+                    // XEP-0091: Legacy Delayed Delivery
+                    const QString str = xElement.attribute("stamp");
+                    d->stamp = QDateTime::fromString(str, "yyyyMMddThh:mm:ss");
+                    d->stamp.setTimeSpec(Qt::UTC);
+                    d->stampType = LegacyDelayedDelivery;
+                }
             } else if (xElement.namespaceURI() == ns_conference) {
                 // XEP-0249: Direct MUC Invitations
                 d->mucInvitationJid = xElement.attribute("jid");
