@@ -482,6 +482,19 @@ void QXmppServer::setLocalCertificate(const QString &path)
         server->setLocalCertificate(d->localCertificate);
 }
 
+/// Sets the local SSL certificate
+///
+/// \param certificate
+
+void QXmppServer::setLocalCertificate(const QSslCertificate &certificate)
+{
+    d->localCertificate = certificate;
+
+    // reconfigure servers
+    foreach (QXmppSslServer *server, d->serversForClients + d->serversForServers)
+        server->setLocalCertificate(d->localCertificate);
+}
+
 /// Sets the path for the local SSL private key.
 ///
 /// \param path
@@ -505,6 +518,19 @@ void QXmppServer::setPrivateKey(const QString &path)
         server->setPrivateKey(d->privateKey);
 }
 
+/// Sets the local SSL private key.
+///
+/// \param key
+
+void QXmppServer::setPrivateKey(const QSslKey &key)
+{
+    d->privateKey = key;
+
+    // reconfigure servers
+    foreach (QXmppSslServer *server, d->serversForClients + d->serversForServers)
+        server->setPrivateKey(d->privateKey);
+}
+
 /// Listen for incoming XMPP client connections.
 ///
 /// \param address
