@@ -33,6 +33,7 @@ private slots:
     void testItems();
     void testItemsResponse();
     void testPublish();
+    void testRetractItem();
     void testSubscribe();
     void testSubscription();
     void testSubscriptions();
@@ -135,6 +136,35 @@ void tst_QXmppPubSubIq::testPublish()
     serializePacket(iq, xml);
 }
 
+void tst_QXmppPubSubIq::testRetractItem()
+{
+    const QByteArray xml(
+        "<iq"
+        " id=\"retract1\""
+        " to=\"pubsub.shakespeare.lit\""
+        " from=\"hamlet@denmark.lit/elsinore\""
+        " type=\"set\">"
+            "<pubsub xmlns=\"http://jabber.org/protocol/pubsub\">"
+                "<retract node=\"princely_musings\">"
+                    "<item id=\"ae890ac52d0df67ed7cfdf51b644e901\"/>"
+                "</retract>"
+            "</pubsub>"
+        "</iq>");
+
+    QXmppPubSubIq iq;
+    parsePacket(iq, xml);
+    QCOMPARE(iq.id(), QString("retract1"));
+    QCOMPARE(iq.to(), QLatin1String("pubsub.shakespeare.lit"));
+    QCOMPARE(iq.from(), QLatin1String("hamlet@denmark.lit/elsinore"));
+    QCOMPARE(iq.type(), QXmppIq::Set);
+    QCOMPARE(iq.queryType(), QXmppPubSubIq::RetractQuery);
+    QCOMPARE(iq.queryJid(), QString());
+    QCOMPARE(iq.queryNode(), QLatin1String("princely_musings"));
+    QCOMPARE(iq.items().size(), 1);
+    QCOMPARE(iq.items().at(0).id(), QString("ae890ac52d0df67ed7cfdf51b644e901"));
+    serializePacket(iq, xml);
+}
+
 void tst_QXmppPubSubIq::testSubscribe()
 {
     const QByteArray xml(
