@@ -24,6 +24,7 @@
 
 #include <QDomDocument>
 #include <QtTest>
+#include "QXmppPasswordChecker.h"
 
 template <class T>
 static void parsePacket(T &packet, const QByteArray &xml)
@@ -46,3 +47,33 @@ static void serializePacket(T &packet, const QByteArray &xml)
     qDebug() << "writing" << buffer.data();
     QCOMPARE(buffer.data(), xml);
 }
+
+class TestPasswordChecker : public QXmppPasswordChecker
+{
+public:
+    void addCredentials(const QString &user, const QString &password)
+    {
+        m_credentials.insert(user, password);
+    };
+
+    /// Retrieves the password for the given username.
+    QXmppPasswordReply::Error getPassword(const QXmppPasswordRequest &request, QString &password)
+    {
+        if (m_credentials.contains(request.username()))
+        {
+            password = m_credentials.value(request.username());
+            return QXmppPasswordReply::NoError;
+        } else {
+            return QXmppPasswordReply::AuthorizationError;
+        }
+    };
+
+    /// Returns whether getPassword() is enabled.
+    bool hasGetPassword() const
+    {
+        return true;
+    };
+
+private:
+    QMap<QString, QString> m_credentials;
+};
